%This script runs the experiments selection algorithm and generates ROC
%curves for the selected datasets.
%IMPORTANT: Please run "Initialize.m" prior to running this script.

queries = input('Enter GO Identifier for category of interest: ');%Enter GO identifier for the GO category of interest
TH = input('Enter threshold for t-test p-value: '); % set threshold for the t-test p-value
seed_size = input('Enter experiment seed size: ');% specify the number of experiments to be used as the seed set.

for nQ = 1:numel(queries)
    qID = queries(nQ);
    bgIDs = getallBGid(qID); %retrieves rest of the GOIDs from the GO, this forms the background set
    queryGOID = [qID bgIDs];
    disp('Retrieving data...')
    [alldata, labels, sizeMat] = getAllData(queryGOID); %extract data from ALL microarrays, for the GOIDs in the queryGOID list
    topExp = getTopExp(sizeMat, seed_size, TH); %gets the top N experiments specified by "seed_size"
    disp('Experiment selection...')
    SelectSet = selectExperiments(topExp, sizeMat, maxExp, TH); %runs the experiment selection algorithm
   
    %%%%%% Generate ROC curves for the selected and all experiments
    disp('Plotting ROC curves...')
        for S = 1:2
            switch(S)
                case(1) %Case 1 uses All experiments
                    exp_retr = [1:maxExp];
                    expLabel = 'All';
                    color = {'r'};
                case(2) %Case 2 uses the Selected experiments
                    exp_retr = SelectSet;
                    expLabel = num2str(exp_retr);
                    color = {'g'};
            end
            [corrM , pval] = getCorrMat(exp_retr,sizeMat, TH);  %prepare correlation matrix with data from chosen experiments
            corrM = abs(corrM);
            cmLength = length(corrM);
            labelMat = zeros(sizeMat,cmLength);  % a zeros matrix of the same size as the cut corr matrix above
            labelMat(1:sizeMat, 1:sizeMat) = 1; % ones in the query GOID matrix , zeros for the background matrix
            corrVec = abs(corrM(:));
            [sortCorr, scidx] = sort(corrVec, 'descend');
            labelVec = labelMat(:);
            sortLabel = labelVec(scidx);
            [auc, prec_at] = get_precision_aucPB(sortCorr, sortLabel,color);
            hold on
            resultAUC(nQ, S) = auc;  % auc = 1-auc
        end
        title(labels(1))  %adds title to the plot drawn by getPrecisionAUC
        %Report generation
        str = strcat(int2str(queryGOID(1)),':',int2str(sizeMat),':',char(labels(1)),' : ', int2str(SelectSet));
        strFig = strcat(int2str(queryGOID(1)));
        dlmwrite('SelectedExperiments.txt', str,'delimiter','','-append')
        print(gcf,'-dpng',strFig)
        close
end
dlmwrite('AUCreport.txt', resultAUC, 'delimiter','\t','-append')
